// src/workers/dev/worker-setup.ts
import { childToWorkerMessages, taskCatalog } from "@trigger.dev/core/v3";
import {
  StandardTaskCatalog,
  TracingSDK
} from "@trigger.dev/core/v3/workers";
import { ZodMessageSender } from "@trigger.dev/core/v3/zodMessageHandler";
import "source-map-support/register.js";

// package.json
var version = "3.0.0-beta.34";

// src/workers/dev/worker-setup.ts
__SETUP_IMPORTED_PROJECT_CONFIG__;
var tracingSDK = new TracingSDK({
  url: process.env.OTEL_EXPORTER_OTLP_ENDPOINT ?? "http://0.0.0.0:4318",
  instrumentations: setupImportedConfig?.instrumentations ?? [],
  diagLogLevel: process.env.OTEL_LOG_LEVEL ?? "none"
});
var otelTracer = tracingSDK.getTracer("trigger-dev-worker", version);
var otelLogger = tracingSDK.getLogger("trigger-dev-worker", version);
var sender = new ZodMessageSender({
  schema: childToWorkerMessages,
  sender: async (message) => {
    process.send?.(message);
  }
});
taskCatalog.setGlobalTaskCatalog(new StandardTaskCatalog());
export {
  otelLogger,
  otelTracer,
  sender,
  tracingSDK
};
